==> bobplates_0.15.12.zip: bobplates_0.15.12/prototypes/item/entities.lua <==
data:extend(
{
  {
    type = "item",
    name = "electrolyser",
    icon = "__bobplates__/graphics/icons/electrolyser.png",
    flags = {"goes-to-quickbar"},
    subgroup = "production-machine",
    order = "e[electrolyser-1]",
    place_result = "electrolyser",
    stack_size = 50
  },

  {
    type = "item",
    name = "mixing-furnace",
    icon = "__bobplates__/graphics/icons/stone-mixing-furnace.png",
    flags = {"goes-to-quickbar"},
    subgroup = "bob-smelting-machine",
    order = "b[mixing-furnace-1]",
    place_result = "mixing-furnace",
    stack_size = 50
  },
  {
    type = "item",
    name = "mixing-steel-furnace",
    icon = "__base__/graphics/icons/steel-furnace.png",
    flags = {"goes-to-quickbar"},
    subgroup = "bob-smelting-machine",
    order = "b[mixing-furnace-2]",
    place_result = "mixing-steel-furnace",
    stack_size = 50
  },
  {
    type = "item",
    name = "electric-mixing-furnace",
    icon = "__bobplates__/graphics/icons/electric-mixing-furnace.png",
    flags = {"goes-to-quickbar"},
    subgroup = "bob-smelting-machine",
    order = "c[electric-mixing-furnace]",
    place_result = "electric-mixing-furnace",
    stack_size = 50
  },

  {
    type = "item",
    name = "chemical-boiler",
    icon = "__bobplates__/graphics/icons/stone-chemical-furnace.png",
    flags = {"goes-to-quickbar"},
    subgroup = "bob-smelting-machine",
    order = "b[chemical-boiler-1]",
    place_result = "chemical-boiler",
    stack_size = 50
  },
  {
    type = "item",
    name = "chemical-steel-furnace",
    icon = "__base__/graphics/icons/steel-furnace.png",
    flags = {"goes-to-quickbar"},
    subgroup = "bob-smelting-machine",
    order = "b[chemical-boiler-2]",
    place_result = "chemical-steel-furnace",
    stack_size = 50
  },
  {
    type = "item",
    name = "chemical-furnace",
    icon = "__bobplates__/graphics/icons/chemical-furnace.png",
    flags = {"goes-to-quickbar"},
    subgroup = "bob-smelting-machine",
    order = "c[chemical-furnace]",
    place_result = "chemical-furnace",
    stack_size = 50
  },


  {
    type = "item",
    name = "air-pump",
    icon = "__bobplates__/graphics/icons/air-pump-1.png",
    flags = {"goes-to-quickbar"},
    subgroup = "bob-pump",
    order = "e[air-pump-1]",
    place_result = "air-pump",
    stack_size = 50
  },

  {
    type = "item",
    name = "air-pump-2",
    icon = "__bobplates__/graphics/icons/air-pump-2.png",
    flags = {"goes-to-quickbar"},
    subgroup = "bob-pump",
    order = "e[air-pump-2]",
    place_result = "air-pump-2",
    stack_size = 50
  },

  {
    type = "item",
    name = "air-pump-3",
    icon = "__bobplates__/graphics/icons/air-pump-3.png",
    flags = {"goes-to-quickbar"},
    subgroup = "bob-pump",
    order = "e[air-pump-3]",
    place_result = "air-pump-3",
    stack_size = 50
  },

  {
    type = "item",
    name = "air-pump-4",
    icon = "__bobplates__/graphics/icons/air-pump-4.png",
    flags = {"goes-to-quickbar"},
    subgroup = "bob-pump",
    order = "e[air-pump-4]",
    place_result = "air-pump-4",
    stack_size = 50
  },


  {
    type = "item",
    name = "water-pump",
    icon = "__bobplates__/graphics/icons/water-pump-1.png",
    flags = {"goes-to-quickbar"},
    subgroup = "bob-pump",
    order = "e[water-pump-1]",
    place_result = "water-pump",
    stack_size = 50
  },

  {
    type = "item",
    name = "water-pump-2",
    icon = "__bobplates__/graphics/icons/water-pump-2.png",
    flags = {"goes-to-quickbar"},
    subgroup = "bob-pump",
    order = "e[water-pump-2]",
    place_result = "water-pump-2",
    stack_size = 50
  },

  {
    type = "item",
    name = "water-pump-3",
    icon = "__bobplates__/graphics/icons/water-pump-3.png",
    flags = {"goes-to-quickbar"},
    subgroup = "bob-pump",
    order = "e[water-pump-3]",
    place_result = "water-pump-3",
    stack_size = 50
  },

  {
    type = "item",
    name = "water-pump-4",
    icon = "__bobplates__/graphics/icons/water-pump-4.png",
    flags = {"goes-to-quickbar"},
    subgroup = "bob-pump",
    order = "e[water-pump-4]",
    place_result = "water-pump-4",
    stack_size = 50
  },


  {
    type = "item",
    name = "void-pump",
    icon = "__bobplates__/graphics/icons/void-pump.png",
    flags = {"goes-to-quickbar"},
    subgroup = "bob-pump",
    order = "void-pump",
    place_result = "void-pump",
    stack_size = 50
  },
}
)

==> bobplates_0.16.5.zip: bobplates_0.16.5/prototypes/item/entities.lua <==
data:extend(
{
  {
    type = "item",
    name = "electrolyser",
    icon = "__bobplates__/graphics/icons/electrolyser.png",
    icon_size = 32,
    flags = {"goes-to-quickbar"},
    subgroup = "production-machine",
    order = "e[electrolyser-1]",
    place_result = "electrolyser",
    stack_size = 50
  },

  {
    type = "item",
    name = "mixing-furnace",
    icon = "__bobplates__/graphics/icons/stone-mixing-furnace.png",
    icon_size = 32,
    flags = {"goes-to-quickbar"},
    subgroup = "bob-smelting-machine",
    order = "b[mixing-furnace-1]",
    place_result = "mixing-furnace",
    stack_size = 50
  },
  {
    type = "item",
    name = "mixing-steel-furnace",
    icon = "__base__/graphics/icons/steel-furnace.png",
    icon_size = 32,
    flags = {"goes-to-quickbar"},
    subgroup = "bob-smelting-machine",
    order = "b[mixing-furnace-2]",
    place_result = "mixing-steel-furnace",
    stack_size = 50
  },
  {
    type = "item",
    name = "electric-mixing-furnace",
    icon = "__bobplates__/graphics/icons/electric-mixing-furnace.png",
    icon_size = 32,
    flags = {"goes-to-quickbar"},
    subgroup = "bob-smelting-machine",
    order = "c[electric-mixing-furnace]",
    place_result = "electric-mixing-furnace",
    stack_size = 50
  },

  {
    type = "item",
    name = "chemical-boiler",
    icon = "__bobplates__/graphics/icons/stone-chemical-furnace.png",
    icon_size = 32,
    flags = {"goes-to-quickbar"},
    subgroup = "bob-smelting-machine",
    order = "b[chemical-boiler-1]",
    place_result = "chemical-boiler",
    stack_size = 50
  },
  {
    type = "item",
    name = "chemical-steel-furnace",
    icon = "__base__/graphics/icons/steel-furnace.png",
    icon_size = 32,
    flags = {"goes-to-quickbar"},
    subgroup = "bob-smelting-machine",
    order = "b[chemical-boiler-2]",
    place_result = "chemical-steel-furnace",
    stack_size = 50
  },
  {
    type = "item",
    name = "chemical-furnace",
    icon = "__bobplates__/graphics/icons/chemical-furnace.png",
    icon_size = 32,
    flags = {"goes-to-quickbar"},
    subgroup = "bob-smelting-machine",
    order = "c[chemical-furnace]",
    place_result = "chemical-furnace",
    stack_size = 50
  },


  {
    type = "item",
    name = "air-pump",
    icon = "__bobplates__/graphics/icons/air-pump-1.png",
    icon_size = 32,
    flags = {"goes-to-quickbar"},
    subgroup = "bob-pump",
    order = "e[air-pump-1]",
    place_result = "air-pump",
    stack_size = 50
  },

  {
    type = "item",
    name = "air-pump-2",
    icon = "__bobplates__/graphics/icons/air-pump-2.png",
    icon_size = 32,
    flags = {"goes-to-quickbar"},
    subgroup = "bob-pump",
    order = "e[air-pump-2]",
    place_result = "air-pump-2",
    stack_size = 50
  },

  {
    type = "item",
    name = "air-pump-3",
    icon = "__bobplates__/graphics/icons/air-pump-3.png",
    icon_size = 32,
    flags = {"goes-to-quickbar"},
    subgroup = "bob-pump",
    order = "e[air-pump-3]",
    place_result = "air-pump-3",
    stack_size = 50
  },

  {
    type = "item",
    name = "air-pump-4",
    icon = "__bobplates__/graphics/icons/air-pump-4.png",
    icon_size = 32,
    flags = {"goes-to-quickbar"},
    subgroup = "bob-pump",
    order = "e[air-pump-4]",
    place_result = "air-pump-4",
    stack_size = 50
  },


  {
    type = "item",
    name = "water-pump",
    icon = "__bobplates__/graphics/icons/water-pump-1.png",
    icon_size = 32,
    flags = {"goes-to-quickbar"},
    subgroup = "bob-pump",
    order = "e[water-pump-1]",
    place_result = "water-pump",
    stack_size = 50
  },

  {
    type = "item",
    name = "water-pump-2",
    icon = "__bobplates__/graphics/icons/water-pump-2.png",
    icon_size = 32,
    flags = {"goes-to-quickbar"},
    subgroup = "bob-pump",
    order = "e[water-pump-2]",
    place_result = "water-pump-2",
    stack_size = 50
  },

  {
    type = "item",
    name = "water-pump-3",
    icon = "__bobplates__/graphics/icons/water-pump-3.png",
    icon_size = 32,
    flags = {"goes-to-quickbar"},
    subgroup = "bob-pump",
    order = "e[water-pump-3]",
    place_result = "water-pump-3",
    stack_size = 50
  },

  {
    type = "item",
    name = "water-pump-4",
    icon = "__bobplates__/graphics/icons/water-pump-4.png",
    icon_size = 32,
    flags = {"goes-to-quickbar"},
    subgroup = "bob-pump",
    order = "e[water-pump-4]",
    place_result = "water-pump-4",
    stack_size = 50
  },


  {
    type = "item",
    name = "void-pump",
    icon = "__bobplates__/graphics/icons/void-pump.png",
    icon_size = 32,
    flags = {"goes-to-quickbar"},
    subgroup = "bob-pump",
    order = "void-pump",
    place_result = "void-pump",
    stack_size = 50
  },
}
)
